@@ -114,7 +114,7 @@ jobs:
     - {toolchain: gcc-10, target_arch: i386, kconfig: tinyconfig}
   tests:
     - {device: qemu-i386}
-    - {device: qemu-i386, tests: [ltp-smoke]}
+    - {device: qemu-i386, tests: [ltp-syscalls], sharding: 3}
 
 - tests:
     - {kernel: https://storage.tuxboot.com/arm64/Image, device: qemu-arm64, tests: [ltp-smoke]}
@@ -305,3 +305,28 @@ def sample_manifest_file(tmp_path, sample_manifest):
     m = tmp_path / "default.xml"
     m.write_text(sample_manifest)
     return str(m)
+
+
+@pytest.fixture
+def build_attrs():
+    return {
+        "group": "tuxsuite",
+        "project": "unittests",
+        "git_repo": "http://github.com/torvalds/linux",
+        "git_ref": "master",
+        "target_arch": "arm",
+        "kconfig": "defconfig",
+        "build_name": "test_build_name",
+        "toolchain": "gcc-9",
+        "token": "test_token",
+        "kbapi_url": "http://test/foo",
+        "tuxapi_url": "http://tuxapi",
+        "kernel_image": "Image",
+    }
+
+
+@pytest.fixture
+def build(build_attrs):
+    b = tuxsuite.build.Build(**build_attrs)
+    b.uid = "myuid"
+    return b
