@@ -211,9 +211,11 @@ class TestBitbake:
             ],
             "name": "",
             "no_cache": False,
+            "is_public": True,
             "bblayers_conf": [],
             "container": bitbake.build_definition.container,
-            "manifest": None,
+            "manifest_file": None,
+            "pinned_manifest": None,
         }
         assert bitbake.generate_build_request() == (expected_data, {})
 
@@ -243,6 +245,7 @@ class TestBitbake:
                 ],
                 "name": "",
                 "no_cache": False,
+                "is_public": True,
                 "artifacts": [],
                 "environment": {},
                 "extraconfigs": [],
@@ -250,6 +253,8 @@ class TestBitbake:
                 "bblayers_conf": [],
                 "container": bitbake.build_definition.container,
                 "manifests": {},
+                "pinned_manifest": None,
+                "manifest_file": None,
             },
         )
 
