@@ -219,6 +219,45 @@ class TestBakeCli:
         tuxsuite.cli.main()
         build.assert_called_once()
 
+    def test_bake_manifest_error(
+        self,
+        monkeypatch,
+        mocker,
+        tmp_path,
+        tuxsuite_config,
+        sample_bitbake_template,
+        capsys,
+    ):
+        template = tmp_path / "yocto.json"
+        template.write_text(sample_bitbake_template)
+        local_manifest = tmp_path / "local_manifest.xml"
+        pinned_manifest = tmp_path / "pinned_manifest.xml"
+        local_manifest.write_text("<manifest></manifest>")
+        pinned_manifest.write_text("<manifest></manifest>")
+        monkeypatch.setattr(
+            sys,
+            "argv",
+            [
+                "tuxsuite",
+                "bake",
+                "submit",
+                f"{template}",
+                "-l",
+                f"{local_manifest}",
+                "-pm",
+                f"{pinned_manifest}",
+            ],
+        )
+        with pytest.raises(SystemExit) as exc:
+            tuxsuite.cli.main()
+        assert exc.value.code == 1
+        assert exc.type == SystemExit
+        output, error = capsys.readouterr()
+        assert (
+            error
+            == "Error: Either local manifest or pinned manifest to be provided, not both\n"
+        )
+
 
 class TestBuildCli:
     def test_build_no_args(self, monkeypatch, tuxsuite_config, capsys):
@@ -422,7 +461,7 @@ class TestBuildCli:
         tuxsuite.cli.main()
         build.build.assert_called_once()
         download_file.assert_called_with(
-            "https://builds.com/21321312312/build.log", mocker.ANY
+            "https://builds.com/21321312312/build.log", mocker.ANY, headers=mocker.ANY
         )
 
     def test_build_download_show_logs(
@@ -779,7 +818,9 @@ class TestPlanCli:
             git_sha=None,
             patch_series=sample_patch_tgz,
             no_cache=False,
-            local_manifest=None,
+            manifest_file=None,
+            pinned_manifest=None,
+            is_public=True,
         )
 
     def test_plan_empty_config(
