@@ -344,7 +344,7 @@ def test_bake_submit(config, bake_plan_config, mocker):
         cfg,
         group="bake_tuxgrp",
         project="bake_tuxprj",
-        local_manifest="https://gitlab.com/alok.ranjan1/test-project/-/blob/main/default.xml",
+        manifest_file="https://gitlab.com/alok.ranjan1/test-project/-/blob/main/default.xml",
     )
 
     def post(url, headers, data):
@@ -393,7 +393,7 @@ def test_bake_plan_extended_config_submit(config, bake_plan_extended_config, moc
         cfg,
         group="bake_tuxgrp",
         project="bake_tuxprj",
-        local_manifest="https://gitlab.com/alok.ranjan1/test-project/-/blob/main/default.xml",
+        manifest_file="https://gitlab.com/alok.ranjan1/test-project/-/blob/main/default.xml",
     )
 
     def post(url, headers, data):
