@@ -5,7 +5,7 @@
 This is the tuxsuite module.
 """
 
-__version__ = "1.5.0"
+__version__ = "1.6.0"
 
 
 from . import build
@@ -178,8 +178,11 @@ class BuildPlan(PlanType):
         for cfg in plan.config.plan:
             if cfg["build"] is not None:
                 data = plan.args.copy()
-                # Ignore bake plan local-manifest option
-                data.pop("local_manifest", None)
+                # Ignore bake plan options
+                data.pop("manifest_file", None)
+                data.pop("pinned_manifest", None)
+                data.pop("is_public", None)
+
                 data.update(cfg["build"])
                 if plan.args.get("no_cache"):
                     data["no_cache"] = True
@@ -232,28 +235,42 @@ class BakePlan(PlanType):
 
     def create_builds(self, plan, builds):
         req_data = {"oebuilds": []}
-        # handling no-cache option
+        # handling options
         no_cache = plan.args.get("no_cache", False)
-        # Ignoring kernel plan build options
+        local_manifest = plan.args.get("manifest_file")
+        pinned_manifest = plan.args.get("pinned_manifest")
+        is_public = plan.args.get("is_public", True)
+
+        # filtering out Bitbake Child class (BuildDefiniton) attributes
         data = {
             key: value
             for key, value in plan.args.items()
-            if key not in ["git_repo", "git_sha", "git_ref", "no_cache", "patch_series"]
+            if key
+            not in [
+                "git_repo",
+                "git_sha",
+                "git_ref",
+                "no_cache",
+                "patch_series",
+                "manifest_file",
+                "pinned_manifest",
+                "is_public",
+            ]
         }
 
-        # handling manifest
-        if data.get("local_manifest", None):
-            local_manifest = data["local_manifest"]
-            (manifest_file, manifest_content) = build.handle_manifest(local_manifest)
+        # handling manifest ( either pinned or local manifest)
+        if local_manifest or pinned_manifest:
+            manifest = local_manifest or pinned_manifest
+            (manifest_file, manifest_content) = build.handle_manifest(manifest)
             req_data["manifests"] = {manifest_file: manifest_content}
 
-        # delete if present
-        data.pop("local_manifest", None)
-
         for cfg in plan.config.plan:
             if cfg["build"] is not None:
                 data["data"] = cfg["build"]
                 data["data"]["no_cache"] = no_cache
+                data["data"]["manifest_file"] = local_manifest
+                data["data"]["pinned_manifest"] = pinned_manifest
+                data["data"]["is_public"] = is_public
                 builds.append(build.Bitbake(**data))
             else:
                 builds.append(None)
@@ -262,7 +279,6 @@ class BakePlan(PlanType):
         if builds_to_submit:
             for b in builds_to_submit:
                 build_entry, _ = b.generate_build_request(plan=plan.plan)
-                del build_entry["manifest"]
                 req_data["oebuilds"].append(build_entry)
 
             ret = build.post_request(f"{plan.url}/oebuilds", plan.headers, req_data)
