@@ -640,7 +640,6 @@ class Plan(HeadersMixin):
             build_data=b.get("build_data"),
             status=b,
             uid=b["uid"],
-            manifest=b.get("manifest"),
             data=build_definition,
         )
         return oebuild
@@ -1048,7 +1047,7 @@ class Bitbake(HeadersMixin):
     data = attrib(default={})
     build_definition = attrib(default={})
     build_data = attrib(default=None)
-    manifest = attrib(default=None)
+    # manifest = attrib(default=None)
 
     @attrs(kw_only=True, order=False)
     class BuildDefinition:
@@ -1063,10 +1062,12 @@ class Bitbake(HeadersMixin):
         local_conf = attrib(default=[])
         bblayers_conf = attrib(default=[])
         container = attrib(default="ubuntu-20.04")
-        manifest = attrib(default=None)
+        manifest_file = attrib(default=None)
         name = attrib(default="")
         no_cache = attrib(default=False)
         extraconfigs = attrib(default=[])
+        pinned_manifest = attrib(default=None)
+        is_public = attrib(default=True)
 
     def __attrs_post_init__(self):
         self.build_definition = self.BuildDefinition(**(self.data))
@@ -1103,20 +1104,30 @@ class Bitbake(HeadersMixin):
         """return a build data in a python dict"""
         manifests = {}
         build_data = self.build_definition.__dict__
-        if self.build_definition.manifest and plan is None:
-            (build_data["manifest_file"], manifest) = handle_manifest(
-                self.build_definition.manifest
-            )
-            manifests[build_data["manifest_file"]] = manifest
-        if plan is not None:
+        if plan is None:
+            # local manifest
+            if self.build_definition.manifest_file:
+                (build_data["manifest_file"], manifest) = handle_manifest(
+                    self.build_definition.manifest_file
+                )
+                manifests[build_data["manifest_file"]] = manifest
+            # pinned manifest
+            if self.build_definition.pinned_manifest:
+                (build_data["pinned_manifest"], manifest) = handle_manifest(
+                    self.build_definition.pinned_manifest
+                )
+                manifests[build_data["pinned_manifest"]] = manifest
+        else:
+            # we are seperately handling manifest for plan
             build_data["plan"] = plan
         return (build_data, manifests)
 
     def build(self, plan=None):
         """Submit the build request"""
+        # Here manifest can either be local or pinned, based upon that will be assigning manifest in data
         data, manifest = self.generate_build_request(plan=plan)
         data["manifests"] = manifest
-        del data["manifest"]
+
         url = self.tuxapi_url + "/v1/groups/{}/projects/{}/oebuilds".format(
             self.group, self.project
         )
