@@ -27,6 +27,32 @@ class Base:
         return cls(**v_kwargs, extra=i_kwargs)
 
 
+@dataclass
+class Bill(Base):
+    @dataclass
+    class Count(Base):
+        builds: int
+        oebuilds: int
+        plans: int
+        tests: int
+
+    @dataclass
+    class Duration(Base):
+        builds: int
+        oebuilds: int
+        tests: int
+
+    group: str
+    date: str
+    count: Count
+    duration: Duration
+    extra: Dict
+
+    def __post_init__(self):
+        self.count = Bill.Count(**self.count)
+        self.duration = Bill.Duration(**self.duration)
+
+
 @dataclass
 class Build(Base):
     project: str
@@ -77,6 +103,42 @@ class Build(Base):
         return f"{self.uid} {icon} {color}{msg}{colors.reset} {self.target_arch}@{self.toolchain}"
 
 
+@dataclass
+class Group(Base):
+    @dataclass
+    class Count(Base):
+        daily: int
+        monthly: int
+        overall: int
+
+    @dataclass
+    class Duration(Base):
+        builds: int
+        oebuilds: int
+        tests: int
+
+    name: str
+    builds: Count
+    oebuilds: Count
+    plans: Count
+    tests: Count
+    duration: Duration
+    limits: Duration
+    lava_devices: List[str]
+    extra: Dict
+
+    def __lt__(self, other):
+        return self.name < other.name
+
+    def __post_init__(self):
+        self.builds = Group.Count(**self.builds)
+        self.oebuilds = Group.Count(**self.oebuilds)
+        self.plans = Group.Count(**self.plans)
+        self.tests = Group.Count(**self.tests)
+        self.duration = Group.Duration(**self.duration)
+        self.limits = Group.Duration(**self.limits)
+
+
 @dataclass
 class Test(Base):
     project: str
