@@ -240,6 +240,10 @@ def handle_list(options, _, config):
 
 
 def handle_submit(cmdargs, _, config):
+
+    if cmdargs.local_manifest and cmdargs.pinned_manifest:
+        error("Either local manifest or pinned manifest to be provided, not both")
+
     if cmdargs.git_head:
         try:
             cmdargs.git_repo, cmdargs.git_sha = tuxsuite.gitutils.get_git_head()
@@ -267,7 +271,9 @@ def handle_submit(cmdargs, _, config):
             git_ref=cmdargs.git_ref,
             patch_series=cmdargs.patch_series,
             no_cache=cmdargs.no_cache,
-            local_manifest=cmdargs.local_manifest,
+            manifest_file=cmdargs.local_manifest,
+            pinned_manifest=cmdargs.pinned_manifest,
+            is_public=cmdargs.private,
         )
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
@@ -333,6 +339,7 @@ def plan_cmd_options(sp):
     sp.add_argument(
         "-l",
         "--local-manifest",
+        default=None,
         help=(
             "Path to a local manifest file which will be used during repo sync. "
             "This input is ignored if sources used is git_trees in the build "
@@ -340,6 +347,17 @@ def plan_cmd_options(sp):
         ),
         type=file_or_url,
     )
+    sp.add_argument(
+        "-pm",
+        "--pinned-manifest",
+        default=None,
+        help=(
+            "Path to a pinned manifest file which will be used during repo sync. "
+            "This input is ignored if sources used is git_trees in the build "
+            "definition. Should be a valid XML. This option is only applicable in case of bake plan."
+        ),
+        type=file_or_url,
+    )
 
 
 def setup_parser(parser):
