@@ -193,10 +193,13 @@ def show_log(build, download, output_dir):
         for line in open(os.path.join(output_dir, build.uid, "build.log")):
             print(line.strip(), file=sys.stderr)
     else:
+        # Authorization header in case of private build
+        headers = {"Authorization": build.headers["Authorization"]}
         if build.status.get("download_url"):
             tuxsuite.download.download_file(
                 os.path.join(build.status["download_url"], "build.log"),
                 sys.stderr.buffer,
+                headers=headers,
             )
         else:
             error("download_url empty")
