@@ -41,3 +41,8 @@ class InvalidToken(TuxSuiteError):
 class Timeout(TuxSuiteError):
     error_help = "A tuxsuite API call failed"
     error_type = "API"
+
+
+class UnsupportedJob(TuxSuiteError):
+    error_help = "Unsupported Job Type"
+    error_type = "configuration"
